==> elasticsearch-java-7.15.1-sources.jar: co/elastic/clients/elasticsearch/_types/NodeRole.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types;

import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;
import co.elastic.clients.util.StringEnum;

@JsonpDeserializable
public enum NodeRole implements StringEnum {
	Master("master"), Data("data"), DataCold("data_cold"), DataContent("data_content"), DataFrozen(
			"data_frozen"), DataHot("data_hot"), DataWarm("data_warm"), Client("client"), Ingest("ingest"), Ml(
					"ml"), VotingOnly("voting_only"), Transform("transform"), RemoteClusterClient(
							"remote_cluster_client"), CoordinatingOnly("coordinating_only");

	private final String jsonValue;

	NodeRole(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final StringEnum.Deserializer<NodeRole> _DESERIALIZER = new StringEnum.Deserializer<>(
			NodeRole.values());
}

==> elasticsearch-java-7.16.2-sources.jar: co/elastic/clients/elasticsearch/_types/NodeRole.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

//----------------------------------------------------
// THIS CODE IS GENERATED. MANUAL EDITS WILL BE LOST.
//----------------------------------------------------

package co.elastic.clients.elasticsearch._types;

import co.elastic.clients.json.JsonEnum;
import co.elastic.clients.json.JsonpDeserializable;
import co.elastic.clients.json.JsonpDeserializer;

/**
 *
 * @see <a href=
 *      "https://github.com/elastic/elasticsearch-specification/tree/98036c3/specification/_types/Node.ts#L63-L81">API
 *      specification</a>
 */
@JsonpDeserializable
public enum NodeRole implements JsonEnum {
	Master("master"),

	Data("data"),

	DataCold("data_cold"),

	DataContent("data_content"),

	DataFrozen("data_frozen"),

	DataHot("data_hot"),

	DataWarm("data_warm"),

	Client("client"),

	Ingest("ingest"),

	Ml("ml"),

	VotingOnly("voting_only"),

	Transform("transform"),

	RemoteClusterClient("remote_cluster_client"),

	CoordinatingOnly("coordinating_only"),

	;

	private final String jsonValue;

	NodeRole(String jsonValue) {
		this.jsonValue = jsonValue;
	}

	public String jsonValue() {
		return this.jsonValue;
	}

	public static final JsonEnum.Deserializer<NodeRole> _DESERIALIZER = new JsonEnum.Deserializer<>(NodeRole.values());
}
